fn finalize_test_machine_mode(
outcome: TestOutcome,
wall_clock: Duration,
) -> Result<()>Expand description
Emit the terminal forge test envelope and exit appropriately under
--machine. Bypasses TestOutcome::ensure_ok’s human output.
fn finalize_test_machine_mode(
outcome: TestOutcome,
wall_clock: Duration,
) -> Result<()>Emit the terminal forge test envelope and exit appropriately under
--machine. Bypasses TestOutcome::ensure_ok’s human output.